@@ -389,9 +389,6 @@ void print_gpu_device_info() {
   std::cout << "  warpSize:                    " << deviceProp.warpSize << std::endl;
   std::cout << "  regsPerBlock:                " << deviceProp.regsPerBlock << std::endl;
   std::cout << "  concurrentKernels:           " << deviceProp.concurrentKernels << std::endl;
-  std::cout << "  clockRate:                   " << deviceProp.clockRate << std::endl;
-  std::cout << "  canMapHostMemory:            " << deviceProp.canMapHostMemory << std::endl;
-  std::cout << "  computeMode:                 " << deviceProp.computeMode << std::endl;
 }
 
 #endif  // EIGEN_GPUCC
